==> blesta-5.10.2.zip: blesta/language/tr_tr/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Ayarları Güncelle';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Müşteri Kullanıcı Adımı Unuttum';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Müşteri Şifremi Sıfırla';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Yönetici Şifremi Sıfırla';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Müşteri Girişi';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Yönetici Girişi';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'reCaptcha Paylaşılan Anahtar';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'reCaptcha Site Anahtarı';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Dahili Captcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Hiçbiri';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Etkin Formlar';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Captcha Sağlayıcı';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'İnsan Doğrulaması';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Ayarları Güncelle';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Paket Arama';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Hizmet Arama';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'İşlem Arama';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Teklif Arama';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Fatura Arama';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Müşteri Arama';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Akıllı Arama';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Ayarları Güncelle';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Müşterilere e-posta pazarlamasına katılma/katılmama seçeneği sunun';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Pazarlama';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Kişi Türünü Düzenle';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Dil Tanımını Kullanın';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'İsim';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Kişi Türünü Düzenle';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Ayarlar > Şirket > Genel > Kişi Türünü Düzenle';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Kişi Türü Oluştur';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Dil Tanımını Kullanın';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'İsim';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Kişi Türü Oluştur';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Ayarlar > Şirket > Genel > Kişi Türü Oluştur';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Bu kutuyu yalnızca özel dil dosyasına bu irtibat tipi için bir dil tanımı eklediyseniz işaretleyin.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'İletişim Türü bulunmamaktadır.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'Bu kişi türünün silinmesi, bu türe atanan tüm kişilerin varsayılan "Faturalama" türüne yerleştirilmesine neden olacaktır. Bu kişi türünü silmek istediğinizden emin misiniz?';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Silme';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'Düzenle';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'Hayır';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Evet';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Seçenekler';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Dil Tanımını Kullanır';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'İsim';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'İletişim Türleri';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Kişi Türü Oluştur';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Ayarlar > Şirket > Genel > Kişi Türleri';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Parolayı Güncelle';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Bu parolayı güvenli bir yere kaydettim';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Özel Anahtar Parolasını Onayla';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Yeni Özel Anahtar Parolası';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Geçerli Özel Anahtar Parolası';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Şifreleme';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'UYARI: Bir parola belirlenmiştir. Parolanızla manuel olarak toplu ödeme yapmanız gerekmektedir. Parolanızı boş bir parolayla değiştirmeniz bu zorunluluğu ortadan kaldıracaktır.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'UYARI: Bir parola belirlemek, yerel olarak depolanan ödeme hesaplarının otomatik olarak işlenmesini önleyecektir. Parolanızı girerek ödemeleri manuel olarak toplu hale getirmeniz gerekecektir. Bu özellik hakkında daha fazla bilgi için lütfen kılavuza bakın.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Ayarlar > Şirket > Genel > Şifreleme';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = '1$s dilini kaldırmak istediğinizden emin misiniz? Bu dil kaldırılacak ve bu dildeki tüm e-posta şablonları kalıcı olarak silinecektir.';
$lang['AdminCompanyGeneral.international.confirm_install'] = '1$s dilini yüklemek istediğinizden emin misiniz?';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Kaldırma';
$lang['AdminCompanyGeneral.international.option_install'] = 'Kurulum';
$lang['AdminCompanyGeneral.international.text_options'] = 'Seçenekler';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Dil';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Uluslararasılaştırma';
$lang['AdminCompanyGeneral.international.page_title'] = 'Ayarlar > Şirket > Genel > Uluslararasılaştırma';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'translate.blesta.com adresinde kitle kaynaklı bir çeviri projesi bulunmaktadır. Oradan dil çevirilerine katkıda bulunabilir ve indirebilirsiniz. Yüklemek için, dosyanın içeriğini Blesta kurulum dizininize açın. Ardından, bu sayfayı yenileyin ve Yükle bağlantısına tıklayın.';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Ayarları Güncelle';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Varsayılan Ülke';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Tarih Saat Formatı';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Tarih Formatı';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Zaman Dilimi';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Pazartesi';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Pazar';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Takvim Başlangıç Günü';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Müşteri Dil ayarlayabilir';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Varsayılan Dil';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Yerelleştirme';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Ayarlar > Şirket > Genel > Yerelleştirme';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Bu varsayılan olarak kullanılan captcha\'dır, Dahili Captcha GD uzantısını gerektirir.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Bu, ilgili formlarda varsayılan olarak seçilen ülkedir.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Tarih ve saat biçimini ayarlar. Bu biçim tarih ve saati görüntülerken kullanılır. Mevcut seçenekler için lütfen php kılavuzuna bakın.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Tarih biçimini ayarlar. Bu biçim bir tarih görüntülenirken kullanılır. Mevcut seçenekler için lütfen php kılavuzuna bakın.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'Bu, tarih ve saat dönüşümlerinin biçimlendirileceği sistem saat dilimidir.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Takvimin haftalık başlangıç gününü ayarlayın.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'İşaretlendiğinde, müşteriler sistemde mevcut olanlar arasından kullanmak için kendi dillerini seçebilirler.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'Sistem tarafından kullanılan varsayılan dil. Daha fazla dil eklemek için Uluslararasılaştırma ayarları bölümüne bakın.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'İnsan doğrulama ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Akıllı Arama ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Pazarlama ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = '1$s dili başarıyla kaldırıldı.';
$lang['AdminCompanyGeneral.!success.language_installed'] = '1$s dili başarıyla yüklendi.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = '"%1$s" kişi türü başarıyla silindi.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = '"%1$s" kişi türü başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = '"%1$s" kişi türü başarıyla eklendi.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Şifreleme ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Yerelleştirme ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'GD uzantısı dahili captcha oluşturmak için gereklidir.';

==> blesta-5.11.4.zip: blesta/language/tr_tr/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Ayarları Güncelle';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Müşteri Kullanıcı Adımı Unuttum';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Müşteri Şifremi Sıfırla';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Yönetici Şifremi Sıfırla';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Müşteri Girişi';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Yönetici Girişi';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'reCaptcha Paylaşılan Anahtar';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'reCaptcha Site Anahtarı';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Dahili Captcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Hiçbiri';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Etkin Formlar';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Captcha Sağlayıcı';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'İnsan Doğrulaması';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Ayarları Güncelle';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Paket Arama';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Hizmet Arama';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'İşlem Arama';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Teklif Arama';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Fatura Arama';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Müşteri Arama';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Akıllı Arama';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Ayarları Güncelle';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Müşterilere e-posta pazarlamasına katılma/katılmama seçeneği sunun';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Pazarlama';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Kişi Türünü Düzenle';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Dil Tanımını Kullanın';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'İsim';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Kişi Türünü Düzenle';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Ayarlar > Şirket > Genel > Kişi Türünü Düzenle';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Kişi Türü Oluştur';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Dil Tanımını Kullanın';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'İsim';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Kişi Türü Oluştur';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Ayarlar > Şirket > Genel > Kişi Türü Oluştur';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Bu kutuyu yalnızca özel dil dosyasına bu irtibat tipi için bir dil tanımı eklediyseniz işaretleyin.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'İletişim Türü bulunmamaktadır.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'Bu kişi türünün silinmesi, bu türe atanan tüm kişilerin varsayılan "Faturalama" türüne yerleştirilmesine neden olacaktır. Bu kişi türünü silmek istediğinizden emin misiniz?';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Silme';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'Düzenle';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'Hayır';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Evet';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Seçenekler';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Dil Tanımını Kullanır';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'İsim';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'İletişim Türleri';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Kişi Türü Oluştur';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Ayarlar > Şirket > Genel > Kişi Türleri';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Parolayı Güncelle';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Bu parolayı güvenli bir yere kaydettim';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Özel Anahtar Parolasını Onayla';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Yeni Özel Anahtar Parolası';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Geçerli Özel Anahtar Parolası';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Şifreleme';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'UYARI: Bir parola belirlenmiştir. Parolanızla manuel olarak toplu ödeme yapmanız gerekmektedir. Parolanızı boş bir parolayla değiştirmeniz bu zorunluluğu ortadan kaldıracaktır.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'UYARI: Bir parola belirlemek, yerel olarak depolanan ödeme hesaplarının otomatik olarak işlenmesini önleyecektir. Parolanızı girerek ödemeleri manuel olarak toplu hale getirmeniz gerekecektir. Bu özellik hakkında daha fazla bilgi için lütfen kılavuza bakın.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Ayarlar > Şirket > Genel > Şifreleme';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Kaldırma';
$lang['AdminCompanyGeneral.international.option_install'] = 'Kurulum';
$lang['AdminCompanyGeneral.international.text_options'] = 'Seçenekler';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Dil';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Uluslararasılaştırma';
$lang['AdminCompanyGeneral.international.page_title'] = 'Ayarlar > Şirket > Genel > Uluslararasılaştırma';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'translate.blesta.com adresinde kitle kaynaklı bir çeviri projesi bulunmaktadır. Oradan dil çevirilerine katkıda bulunabilir ve indirebilirsiniz. Yüklemek için, dosyanın içeriğini Blesta kurulum dizininize açın. Ardından, bu sayfayı yenileyin ve Yükle bağlantısına tıklayın.';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Ayarları Güncelle';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Varsayılan Ülke';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Tarih Saat Formatı';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Tarih Formatı';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Zaman Dilimi';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Pazartesi';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Pazar';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Takvim Başlangıç Günü';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Müşteri Dil ayarlayabilir';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Varsayılan Dil';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Yerelleştirme';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Ayarlar > Şirket > Genel > Yerelleştirme';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Bu varsayılan olarak kullanılan captcha\'dır, Dahili Captcha GD uzantısını gerektirir.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Bu, ilgili formlarda varsayılan olarak seçilen ülkedir.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Tarih ve saat biçimini ayarlar. Bu biçim tarih ve saati görüntülerken kullanılır. Mevcut seçenekler için lütfen php kılavuzuna bakın.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Tarih biçimini ayarlar. Bu biçim bir tarih görüntülenirken kullanılır. Mevcut seçenekler için lütfen php kılavuzuna bakın.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'Bu, tarih ve saat dönüşümlerinin biçimlendirileceği sistem saat dilimidir.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Takvimin haftalık başlangıç gününü ayarlayın.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'İşaretlendiğinde, müşteriler sistemde mevcut olanlar arasından kullanmak için kendi dillerini seçebilirler.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'Sistem tarafından kullanılan varsayılan dil. Daha fazla dil eklemek için Uluslararasılaştırma ayarları bölümüne bakın.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'İnsan doğrulama ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Akıllı Arama ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Pazarlama ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = '"%1$s" kişi türü başarıyla silindi.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = '"%1$s" kişi türü başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = '"%1$s" kişi türü başarıyla eklendi.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Şifreleme ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Yerelleştirme ayarları başarıyla güncellendi.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'GD uzantısı dahili captcha oluşturmak için gereklidir.';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = 'Dili %1$s kaldırmak istediğinizden emin misiniz? Bu dil kaldırılacak ve bu dildeki tüm e-posta şablonları kalıcı olarak silinecektir.';
$lang['AdminCompanyGeneral.international.confirm_install'] = 'Dili %1$s yüklemek istediğinizden emin misiniz?';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = 'Dil %1$s başarıyla kaldırıldı.';
$lang['AdminCompanyGeneral.!success.language_installed'] = '%1$s dili başarıyla yüklendi. E-postaları, paketleri ve paket gruplarını yeni dil için içerikle güncellemeyi unutmayın.';
